"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = exports.createAlias = void 0;
var fs = require("fs");
var path = require("path");
var fse = require("fs-extra");
function createAlias(alias, createAliasOptions) {
    if (createAliasOptions === void 0) { createAliasOptions = {
        root: '.',
        baseUrl: '.',
        jsconfig: undefined,
        tsconfig: undefined,
    }; }
    var _a = __assign({ root: '.', baseUrl: '.', jsconfig: undefined, tsconfig: undefined }, createAliasOptions), root = _a.root, baseUrl = _a.baseUrl, jsconfig = _a.jsconfig, tsconfig = _a.tsconfig;
    var paths = {};
    Object.keys(alias).forEach(function (key) {
        var aliasPath = alias[key];
        paths["".concat(key, "/*")] = ["".concat(aliasPath, "/*")];
    });
    var jsconfigContent = {
        compilerOptions: {
            baseUrl: baseUrl,
            paths: paths,
        },
    };
    if (jsconfig) {
        if (Array.isArray(jsconfig)) {
            jsconfig.forEach(function (configPath) {
                updateOrCreateConfigFile(path.resolve(root, configPath), jsconfigContent);
            });
        }
        else {
            updateOrCreateConfigFile(path.resolve(root, jsconfig), jsconfigContent);
        }
    }
    var tsconfigContent = {
        compilerOptions: {
            baseUrl: baseUrl,
            paths: paths,
        },
    };
    if (tsconfig) {
        if (Array.isArray(tsconfig)) {
            tsconfig.forEach(function (configPath) {
                updateOrCreateConfigFile(path.resolve(root, configPath), tsconfigContent);
            });
        }
        else {
            updateOrCreateConfigFile(path.resolve(root, tsconfig), tsconfigContent);
        }
    }
    return alias;
}
exports.createAlias = createAlias;
exports.default = createAlias;
function updateOrCreateConfigFile(configPath, content) {
    fse.ensureDirSync(path.dirname(configPath));
    try {
        var existingConfig = JSON.parse(fs.readFileSync(configPath, 'utf-8'));
        var mergedConfig = __assign(__assign({}, existingConfig), content);
        fs.writeFileSync(configPath, JSON.stringify(mergedConfig, null, 2));
    }
    catch (error) {
        if (error.code === 'ENOENT') {
            fs.writeFileSync(configPath, JSON.stringify(content, null, 2));
        }
        else {
            throw error;
        }
    }
}
